# Summary

- [Introduction](./introduction.md)
- [Installation](./install.md)
- [Command Basics](./commands.md)
- [Configuration](./configuration.md)
	- [Python Jobs](./python.md)
	- [Apptainer Jobs](./apptainer.md)
- [Python Api](./python_api.md)
- [Available Capabilities](capabilities.md)
- [Machines](machines.md)
